Description
-----------

Python schema library agnostic from languages.

.. image:: https://img.shields.io/pypi/l/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: License

.. image:: https://img.shields.io/pypi/status/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: Development Status

.. image:: https://img.shields.io/pypi/v/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/implementation/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/wheel/b3j0f.schema.svg
   :target: https://travis-ci.org/b3j0f/schema
   :alt: Download format

.. image:: https://travis-ci.org/b3j0f/schema.svg?branch=master
   :target: https://travis-ci.org/b3j0f/schema
   :alt: Build status

.. image:: https://coveralls.io/repos/b3j0f/schema/badge.png
   :target: https://coveralls.io/r/b3j0f/schema
   :alt: Code test coverage

.. image:: https://img.shields.io/pypi/dm/b3j0f.schema.svg
   :target: https://pypi.python.org/pypi/b3j0f.schema/
   :alt: Downloads

.. image:: https://readthedocs.org/projects/b3j0fschema/badge/?version=master
   :target: https://readthedocs.org/projects/b3j0fschema/?badge=master
   :alt: Documentation Status

.. image:: https://landscape.io/github/b3j0f/schema/master/landscape.svg?style=flat
   :target: https://landscape.io/github/b3j0f/schema/master
   :alt: Code Health

Links
-----

- `Homepage`_
- `PyPI`_
- `Documentation`_

Installation
------------

pip install b3j0f.schema

Features
--------

This library provides an abstraction layer for manipulating schema from several languages.

Example
-------

Perspectives
------------

- wait feedbacks during 6 months before passing it to a stable version.
- Cython implementation.

Donation
--------

.. image:: https://cdn.rawgit.com/gratipay/gratipay-badge/2.3.0/dist/gratipay.png
   :target: https://gratipay.com/b3j0f/
   :alt: I'm grateful for gifts, but don't have a specific funding goal.

.. _Homepage: https://github.com/b3j0f/schema
.. _Documentation: http://b3j0fschema.readthedocs.org/en/master/
.. _PyPI: https://pypi.python.org/pypi/b3j0f.schema/
